#!/usr/bin/env python
# -*- coding: utf-8 -*-
### BEGIN LICENSE
# Copyright (C) 2010 Skyler Lehmkuhl
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

###################### DO NOT TOUCH THIS (HEAD TO THE SECOND PART) ######################

import os
import sys

try:
    import DistUtilsExtra.auto
except ImportError:
    print >> sys.stderr, 'To build swift-swf you need https://launchpad.net/python-distutils-extra'
    sys.exit(1)
assert DistUtilsExtra.auto.__version__ >= '2.18', 'needs DistUtilsExtra.auto >= 2.18'

def update_data_path(prefix, oldvalue=None):

    try:
        fin = file('swift_swf/swift_swfconfig.py', 'r')
        fout = file(fin.name + '.new', 'w')

        for line in fin:            
            fields = line.split(' = ') # Separate variable from value
            if fields[0] == '__swift_swf_data_directory__':
                # update to prefix, store oldvalue
                if not oldvalue:
                    oldvalue = fields[1]
                    line = "%s = '%s'\n" % (fields[0], prefix)
                else: # restore oldvalue
                    line = "%s = %s" % (fields[0], oldvalue)
            fout.write(line)

        fout.flush()
        fout.close()
        fin.close()
        os.rename(fout.name, fin.name)
    except (OSError, IOError), e:
        print ("ERROR: Can't find swift_swf/swift_swfconfig.py")
        sys.exit(1)
    return oldvalue


def update_desktop_file(datadir):

    try:
        fin = file('swift-swf.desktop.in', 'r')
        fout = file(fin.name + '.new', 'w')

        for line in fin:            
            if 'Icon=' in line:
                line = "Icon=%s\n" % (datadir + 'media/icon.png')
            fout.write(line)
        fout.flush()
        fout.close()
        fin.close()
        os.rename(fout.name, fin.name)
    except (OSError, IOError), e:
        print ("ERROR: Can't find swift-swf.desktop.in")
        sys.exit(1)


class InstallAndUpdateDataDirectory(DistUtilsExtra.auto.install_auto):
    def run(self):
        previous_value = update_data_path(self.prefix + '/share/swift-swf/')
        update_desktop_file(self.prefix + '/share/swift-swf/')
        DistUtilsExtra.auto.install_auto.run(self)
        update_data_path(self.prefix, previous_value)
        a = os.system("xdg-mime install --mode system /usr/share/swift-swf/media/swift-swift.xml")
        print "xdg running"
        b = os.system("xdg-icon-resource install --context mimetypes --size 48 --mode system /usr/share/swift-swf/media/swift-file.png application-x-swift")
        

        
##################################################################################
###################### YOU SHOULD MODIFY ONLY WHAT IS BELOW ######################
##################################################################################

DistUtilsExtra.auto.setup(
    name='swift-swf',
    version='11.02-public4',
    license='GPL-3',
    author='Skyler Lehmkuhl',
    author_email='skykooler@yahoo.com',
    description='Open source replacement for Adobe Flash',
    url='https://launchpad.net/swift-swf',
    long_description='SWIFT (which stands for "ShockWave Is Free Territory") is an open-source animated content creator. Besides creating .SWFs, it can also create HTML5 content, making your web apps future-proof. SWIFT includes an ActionScript editor to bring advanced functionality to your applications. SWIFT uses swfc for compiling and GNASH for playback. I haven\'t figured out how to add these as dependencies yet, so you will need to install them yourself. If they are not in your repositories, you can download swfc from http://www.swftools.org/ and GNASH from http://www.gnu.org/software/gnash/.',
    cmdclass={'install': InstallAndUpdateDataDirectory}
    )

