# -*- coding: utf-8 -*-
### BEGIN LICENSE
# Copyright (C) 2010 Skyler Lehmkuhl
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

import sys
import os
import gtk

from swift_swf.swift_swfconfig import getdatapath

class ImportDialog(gtk.Dialog):
    __gtype_name__ = "ImportDialog"

    def __init__(self):
        """__init__ - This function is typically not called directly.
        Creation of a ImportDialog requires redeading the associated ui
        file and parsing the ui definition extrenally, 
        and then calling ImportDialog.finish_initializing().
    
        Use the convenience function NewImportDialog to create 
        a ImportDialog object.
    
        """
        pass

    def finish_initializing(self, builder):
        """finish_initalizing should be called after parsing the ui definition
        and creating a ImportDialog object with it in order to finish
        initializing the start of the new ImportDialog instance.
    
        """
        #get a reference to the builder and set up the signals
        self.builder = builder
        self.builder.connect_signals(self)
        Filter = gtk.FileFilter()
        Filter.add_pattern("*.png")
        self.builder.get_object("filechooserdialog1").add_filter(Filter)


    def ok(self, widget, data=None):
        """ok - The user has elected to save the changes.
        Called before the dialog returns gtk.RESONSE_OK from run().

        """
        pass

    def cancel(self, widget, data=None):
        """cancel - The user has elected cancel changes.
        Called before the dialog returns gtk.RESPONSE_CANCEL for run()

        """         
        pass

def NewImportDialog():
    """NewImportDialog - returns a fully instantiated
    dialog-camel_case_nameDialog object. Use this function rather than
    creating ImportDialog instance directly.
    
    """

    #look for the ui file that describes the ui
    ui_filename = os.path.join(getdatapath(), 'ui', 'ImportDialog.ui')
    if not os.path.exists(ui_filename):
        ui_filename = None

    builder = gtk.Builder()
    builder.add_from_file(ui_filename)    
    dialog = builder.get_object("filechooserdialog1")
    #dialog.finish_initializing(builder)
    dialog.set_current_folder("/home/"+os.getlogin()+"/")
    def update_preview_cb(file_chooser, preview):
        filename = file_chooser.get_preview_filename()
        try:
          pixbuf = gtk.gdk.pixbuf_new_from_file_at_size(filename, 128, 128)
          preview.set_from_pixbuf(pixbuf)
          have_preview = True
        except:
          have_preview = False
        file_chooser.set_preview_widget_active(have_preview)
        return
    preview = gtk.Image()
    dialog.set_preview_widget(preview)
    dialog.connect("update-preview", update_preview_cb, preview)
    filter1 = gtk.FileFilter()
    filter2 = gtk.FileFilter()
    filter3 = gtk.FileFilter()
    filter1.set_name("Image files (.png, .jpg)")
    filter2.set_name("Sound files (.mp3)")
    filter3.set_name("All supported files (.png, .jpg, .mp3)")
    filter1.add_pattern("*.png")
    filter1.add_pattern("*.jpg")
    filter2.add_pattern("*.mp3")
    filter3.add_pattern("*.png")
    filter3.add_pattern("*.jpg")
    filter3.add_pattern("*.mp3")
    dialog.add_filter(filter1)
    dialog.add_filter(filter2)
    dialog.add_filter(filter3)


    return dialog

if __name__ == "__main__":
    dialog = NewImportDialog()
    dialog.show()
    gtk.main()

